@@ -20,7 +20,7 @@
 */
 
 /*
- * $Id: gama-g3.cpp,v 1.13 2004/05/12 18:29:17 cepek Exp $
+ * $Id: gama-g3.cpp,v 1.6 2004/01/25 11:07:13 cepek Exp $
  */
 
 #include <fstream>
@@ -145,136 +145,53 @@ namespace
   }
 }
 
-int main_g3()
-{
-  using namespace std;
-  using namespace GNU_gama::g3;
-
-  Model* model = get_xml_input(input);
-  if (model == 0) return error("error on reading XML input data");
-  
-  cerr.precision(12);
-  Model::ObservationData::iterator i = model->obsdata.begin();
-  Model::ObservationData::iterator e = model->obsdata.end();
-  while (i != e)
-    {
-      cerr << "* ";
-      if (Distance *d = dynamic_cast<Distance*>(*i))
-        {
-          cerr << " distance : from = "
-               << d->from
-               << "  to = "
-               << d->to
-               << "  val = "
-               << d->obs();
-          
-          if (d->from_dh || d->to_dh)
-            {
-              cerr << " ( ";
-              cerr << d->from_dh << " ";
-              cerr << d->to_dh << " ";
-              cerr << ")";
-            }              
-        }
-      if (ZenithAngle *d = dynamic_cast<ZenithAngle*>(*i))
-        {
-          cerr << " zenith   : from = "
-               << d->from
-               << "  to = "
-               << d->to
-               << "  val = "
-               << d->obs();
-          
-          if (d->from_dh || d->to_dh)
-            {
-              cerr << " ( ";
-              cerr << d->from_dh << " ";
-              cerr << d->to_dh << " ";
-              cerr << ")";
-            }              
-        }
-      if (Vector* v = dynamic_cast<Vector*>(*i))
-        {
-          cerr << " vector   : from = "
-               << v->from
-               << "  to = " 
-               << v->to
-               << "  dx = "
-               << v->dx()
-               << "  dy = "
-               << v->dy()
-               << "  dz = "
-               << v->dz();
-          
-          if (v->from_dh || v->to_dh)
-            {
-              cerr << " ( ";
-              cerr << v->from_dh << " ";
-              cerr << v->to_dh << " ";
-              cerr << ")";
-            }              
-        }
-      if (XYZ* x = dynamic_cast<XYZ*>(*i))
-        {
-          cerr << " xyz      : id  = "
-               << x->id
-               << "  x = "
-               << x->x()
-               << "  y = "
-               << x->y()
-               << "  z = "
-               << x->z();
-        }
-      cerr << "\n";
-      ++i;
-    }
-  
-  model->update_linearization();
-  
-  if (projeq) 
-    {
-      std::ofstream out(projeq);
-      out.precision(16);
-      out << GNU_gama::DataParser::xml_start;
-      model->write_xml_adjustment_input_data(out);
-      out << GNU_gama::DataParser::xml_end;
-    }
-
-  model->update_adjustment();
-
-  if (output)
-    {
-      ofstream file(output);
-      if (file) 
-        model->write_xml_adjustment_results(file);
-      else
-        std::cerr << "\n****** error on opening file " << output << "\n\n";
-    }
-  else
-    {
-      model->write_xml_adjustment_results(std::cout);
-    }
-  
-  delete model;
-  return 0;
-}
-
 // ----------------------------------------------------------------------
 
 int main(int argc, char* argv[])
 {
-  using namespace GNU_gama::g3;
-
   if (help(argc, argv)) return 1;
 
-  try 
-    {
-      return main_g3();
-    }
-  catch(...)
-    {
-      std::cerr << "\n### gama-g3 : unknown exception\n";
-    }
+  using namespace GNU_gama::g3;
 
-  return 1;
+  Model* model = get_xml_input(input);
+  if (model == 0) return 0; // ??? error("error on reading XML input data");
+  
+  if (model) 
+    {
+      using namespace std;
+      cerr.precision(12);
+      Model::ObservationData::iterator i = model->obsdata.begin();
+      Model::ObservationData::iterator e = model->obsdata.end();
+      while (i != e)
+        {
+          cerr << "* ";
+          if (Distance *d = dynamic_cast<Distance*>(*i))
+            {
+              cerr << " distance : from = "
+                   << d->from
+                   << "  to = "
+                   << d->to
+                   << "  val = "
+                   << d->obs();
+              
+            }
+          cerr << "\n";
+          ++i;
+        }
+
+      model->update_linearization();
+
+      if (projeq) 
+        {
+          std::ofstream out(projeq);
+          out.precision(16);
+          out << GNU_gama::DataParser::xml_start;
+          model->write_xml_adjustment_input_data(out);
+          out << GNU_gama::DataParser::xml_end;
+        }
+    }
+  
+  delete model;
+
+  return 0;
 }
