@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: gama-local-main.h,v 1.17 2004/05/01 13:56:31 cepek Exp $
+ *  $Id: gama-local-main.h,v 1.12 2003/08/07 20:38:20 cepek Exp $
  */
 
 #ifndef GAMA_MAIN__gama_main__gm_mn__g_m__g______________________________h___
@@ -78,9 +78,8 @@ int help()
   cerr << "Options:\n"
        << "\n";
   cerr << "--algorithm  svd | gso\n" 
-       << "--language   en | ca | cz | du | fi | hu\n"
+       << "--language   en | cz | fi | du\n"
        << "--encoding   utf-8 | iso-8859-2 | iso-8859-2-flat | cp-1250\n"
-       << "--angles     400 | 360\n"  
        << "--version\n"
        << "--help\n";
   cerr << endl;
@@ -111,7 +110,6 @@ int GaMa_Main(int argc, char **argv)
   const char* argv_algo = 0;
   const char* argv_lang = 0;
   const char* argv_enc  = 0;
-  const char* argv_angles = 0;
 
   for (int i=1; i<argc; i++)
     {
@@ -142,7 +140,6 @@ int GaMa_Main(int argc, char **argv)
       else if (name == "algorithm") argv_algo = c; 
       else if (name == "language" ) argv_lang = c;
       else if (name == "encoding" ) argv_enc  = c;
-      else if (name == "angles"   ) argv_angles = c;
       else
         return help();
     }
@@ -153,12 +150,10 @@ int GaMa_Main(int argc, char **argv)
   else
     {
       if (!strcmp("en", argv_lang)) set_gama_language(en);
-      else if (!strcmp("ca", argv_lang)) set_gama_language(ca);
       else if (!strcmp("cs", argv_lang)) set_gama_language(cz);
       else if (!strcmp("cz", argv_lang)) set_gama_language(cz);
-      else if (!strcmp("du", argv_lang)) set_gama_language(du);
       else if (!strcmp("fi", argv_lang)) set_gama_language(fi);
-      else if (!strcmp("hu", argv_lang)) set_gama_language(hu);
+      else if (!strcmp("du", argv_lang)) set_gama_language(du);
       else return help();
     }
 
@@ -196,16 +191,6 @@ int GaMa_Main(int argc, char **argv)
         else return help();
       }
 
-      if (argv_angles)
-        {
-          if (!strcmp("400", argv_angles))
-            IS->set_gons();
-          else if (!strcmp("360", argv_angles))
-            IS->set_degrees();
-          else
-            return help();
-        }
-
     }
     catch (...) {
       throw 
@@ -285,10 +270,7 @@ int GaMa_Main(int argc, char **argv)
           IS->apriori_m_0(gkf.m0_apr );
           IS->conf_pr    (gkf.konf_pr);
           IS->tol_abs    (gkf.tol_abs);
-
-          // added in 1.7.09
-          IS->update_constrained_coordinates(gkf.update_constr);
- 
+          
           if (gkf.typ_m0_apriorni)
             IS->set_m_0_apriori();
           else
