@@ -20,7 +20,7 @@
 */
 
 /*
- *  $Id: g3_model.cpp,v 1.29 2004/05/17 16:20:25 cepek Exp $
+ *  $Id: g3_model.cpp,v 1.23 2004/01/25 11:07:13 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
@@ -39,8 +39,7 @@ Model::Model()
 
   points     = new PointBase;
   active_obs = new ObservationList;
-  par_list   = new ParameterList;
-  adj        = new Adj;
+  par_list    = new ParameterList;
 
   points->set_common_data(this); 
   set(&ellipsoid, ellipsoid_wgs84);
@@ -51,10 +50,9 @@ Model::Model()
 
 Model::~Model()
 {
-  delete  points;
-  delete  active_obs;
-  delete  par_list;
-  delete  adj;
+  delete points;
+  delete active_obs;
+  delete par_list;
 }
 
 
@@ -146,13 +144,9 @@ void Model::write_xml(std::ostream& out) const
 
 void Model::update_index(Parameter& p)
 {
-  if (!p.has_index()) 
+  if (!p.index()) 
     {
-      if (p.free())
-        p.set_index(++dm_cols);
-      else
-        p.set_index(1);
-
+      p.set_index(++dm_cols);
       par_list->push_back(&p);
     }
 }
@@ -173,48 +167,48 @@ void Model::update_parameters()
     {
       Point* point = (*i);
  
-      point->N.set_index(0);
-      point->E.set_index(0);
-      point->U.set_index(0);
+      point->N_.set_index(0);
+      point->E_.set_index(0);
+      point->U_.set_index(0);
 
 
       if (point->fixed_horizontal_position())
         {
-          point->N.set_fixed();
-          point->E.set_fixed();
+          point->N_.set_fixed();
+          point->E_.set_fixed();
         }
       else if (point->constr_horizontal_position())
         {
-          point->N.set_constr();
-          point->E.set_constr();
+          point->N_.set_constr();
+          point->E_.set_constr();
         }
       else if (point->free_horizontal_position())
         {
-          point->N.set_free();
-          point->E.set_free();
+          point->N_.set_free();
+          point->E_.set_free();
         }
       else
         {
-          point->N.set_unused();
-          point->E.set_unused();
+          point->N_.set_unused();
+          point->E_.set_unused();
         }
       
 
       if (point->fixed_height())
         {
-          point->U.set_fixed();
+          point->U_.set_fixed();
         }
       else if (point->constr_height())
         {
-          point->U.set_constr();
+          point->U_.set_constr();
         }
       else if (point->free_height())
         {
-          point->U.set_free();
+          point->U_.set_free();
         }
       else
         {
-          point->U.set_unused();
+          point->U_.set_unused();
         }
     }
 
@@ -250,21 +244,20 @@ void Model::update_linearization()
 {
   if (!check_observations()) update_observations();
 
-  cerr << "- - - - - - - - - - - - - - - - - - - - - - - .\n";
-  adj_input_data = new AdjInputData;
-
   A = new SparseMatrix<>(dm_floats, dm_rows, dm_cols);
   rhs.reset(dm_rows);
   rhs_ind = 0;
 
+  // delete B;   B = new BlockDiagonal<>;
+
   for (ObservationList::iterator 
          i=active_obs->begin(), e=active_obs->end(); i!=e; ++i)
     {
       (*i)->linearization_accept(this);
     }
 
-  adj_input_data->set_mat(A);
-  adj_input_data->set_rhs(rhs);
+  adj_input_data.set_mat(A);
+  adj_input_data.set_rhs(rhs);
 
   {
     int minx=0;
@@ -289,7 +282,7 @@ void Model::update_linearization()
               }
           }
         
-        adj_input_data->set_minx(minlist);
+        adj_input_data.set_minx(minlist);
       }
   }
   
@@ -318,10 +311,8 @@ void Model::update_linearization()
           }
       }
 
-    adj_input_data->set_cov(bd);
+    adj_input_data.set_cov(bd);
   }
-    
-  adj->set(adj_input_data);
 
   return next_state_(linear_);
 }
@@ -329,87 +320,13 @@ void Model::update_linearization()
 
 void Model::update_adjustment()
 {
-  cerr << "\n************ void Model::update_adjustment()\n\n";
   if (!check_linearization()) update_linearization();
 
-  cerr << "x() = " << adj->x();
-  for (ParameterList::iterator 
-         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
-    {
-      Parameter* p = *i;
-      if (int k = p->index()) p->set_correction(adj->x()(k));
-    }
-  
-
-  cerr << "\n------------ void Model::update_adjustment()\n\n";
   return next_state_(adjust_);
 }
 
 
 void Model::write_xml_adjustment_input_data(std::ostream& out)
 {
-  if (!check_linearization()) update_linearization();
-
-  /* see also : GNU_gama::DataParser::xml_start  *
-   *            GNU_gama::DataParser::xml_end    */
-  adj_input_data->write_xml(out);
+  adj_input_data.write_xml(out);
 }
-
-
-void Model::write_xml_adjustment_results(std::ostream& out)
-{
-  if (!check_adjustment()) update_adjustment();
-
-  out << 
-    "\n<!-- adjustment results  :"
-    " dn / de / du  are in millimeters -->\n\n";
-  
-  out << "<adjustment-results>\n";
-
-  for (ParameterList::iterator 
-         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
-    {
-      (*i)->write_xml_init();
-    }
-  for (ParameterList::iterator 
-         i=par_list->begin(), e=par_list->end(); i!=e; ++i)
-    {
-      (*i)->write_xml(out);
-    }
-  
-  out << "\n</adjustment-results>\n";
-}
-
-
-GNU_gama::E_3 Model::vector(const Point* from, const Point* to) const
-{
-  GNU_gama::E_3 v;
-  
-  v.set(to  ->X(), to  ->Y(), to  ->Z());
-  v.sub(from->X(), from->Y(), from->Z());
-
-  return v;
-}
-
-
-GNU_gama::E_3 Model::normal(const Point* p) const
-{
-  const double B = p->B();
-  const double L = p->L();
-
-  return GNU_gama::E_3(std::cos(B)*std::cos(L),
-                       std::cos(B)*std::sin(L),
-                       std::sin(B)            );
-}
-
-
-GNU_gama::E_3 Model::vertical(const Point* p) const
-{
-  const double B = p->B() + p->dB();
-  const double L = p->L() + p->dL();
-
-  return GNU_gama::E_3(std::cos(B)*std::cos(L),
-                       std::cos(B)*std::sin(L),
-                       std::sin(B)            );
-}
-
