@@ -20,13 +20,61 @@
 */
 
 /*
- *  $Id: g3_model_distance.cpp,v 1.8 2004/04/23 22:01:31 cepek Exp $
+ *  $Id: g3_model_distance.cpp,v 1.1 2004/01/25 11:07:13 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
 
 using namespace GNU_gama::g3;
 
+//---  namespace {
+//---  
+//---    struct distance
+//---    {
+//---      Point   *A, *B;
+//---      double   Na, Ea, Ua,  Nb, Eb, Ub;
+//---  
+//---      distance(Point* a, Point* b, double ua, double ub)
+//---        : A(a), B(b), Na(0.), Ea(0.), Ua(ua), Nb(0.), Eb(0.), Ub(ub)
+//---      {
+//---      }
+//---  
+//---      double value()
+//---      {
+//---        double dx 
+//---          = B->X() + B->x_transform(Nb, Eb, Ub)
+//---          - A->X() - A->x_transform(Na, Ea, Ua);
+//---  
+//---        double dy 
+//---          = B->Y() + B->y_transform(Nb, Eb, Ub)
+//---          - A->Y() - A->y_transform(Na, Ea, Ua);
+//---  
+//---        double dz 
+//---          = B->Z() + B->z_transform(Nb, Eb, Ub)
+//---          - A->Z() - A->z_transform(Na, Ea, Ua);
+//---  
+//---        return std::sqrt(dx*dx + dy*dy + dz*dz);
+//---      }
+//---  
+//---      double d(double& p)
+//---      {
+//---        const double diff = 0.5;
+//---        double dd, tmp = p;
+//---  
+//---        p  += diff;
+//---        dd  = value();
+//---        p  -= 2*diff;
+//---        dd -= value();
+//---        dd /= (2*diff);
+//---  
+//---        p = tmp;
+//---        return dd;
+//---      }
+//---  
+//---    };
+//---  }
+
+
 bool Model::revision_visit(Distance* d)
 {
   if (!d->active()) return false;
@@ -41,19 +89,30 @@ bool Model::revision_visit(Distance* d)
 
   active_obs->push_back(d);
 
-  update_index(from->N);
-  update_index(from->E);
-  update_index(from->U);
-  update_index(to  ->N);
-  update_index(to  ->E);
-  update_index(to  ->U);
-  
   dm_rows += d->dimension();            // design matrix
+  if (from->free_horizontal_position())
+    {
+      update_index(from->N_);
+      update_index(from->E_);
+      dm_floats += 2;
+    }
+  if (from->free_height())
+    {
+      update_index(from->U_);
+      dm_floats += 1;
+    }
 
-  if (from->free_horizontal_position())  dm_floats += 2;
-  if (from->free_height())               dm_floats += 1;
-  if (to  ->free_horizontal_position())  dm_floats += 2;
-  if (to  ->free_height())               dm_floats += 1;
+  if (to->free_horizontal_position())
+    {
+      update_index(to->N_);
+      update_index(to->E_);
+      dm_floats += 2;
+    }
+  if (to->free_height())
+    {
+      update_index(to->U_);
+      dm_floats += 1;
+    }
 
   return d->active();
 }
@@ -64,6 +123,7 @@ void Model::linearization_visit(Distance* d)
   Point* from = points->find(d->from);
   Point* to   = points->find(d->to  );
 
+
   {
     double dx = to->X() - from->X();
     double dy = to->Y() - from->Y();
@@ -80,7 +140,7 @@ void Model::linearization_visit(Distance* d)
 
 
 
-  // nonzero derivatives in project equations
+  // nonzero derivatives in proeject equations
   A->new_row();
   if (from->free_horizontal_position())
     {
@@ -111,7 +171,7 @@ void Model::linearization_visit(Distance* d)
     double dz = to->Z_dh(d->to_dh) - from->Z_dh(d->from_dh);
     double D  = std::sqrt(dx*dx + dy*dy + dz*dz);
 
-    rhs(++rhs_ind) = d->obs() - D;
+    rhs(++rhs_ind) = D - d->obs();
   }
 }
 
