@@ -19,7 +19,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: g3_parameter.h,v 1.19 2004/04/21 16:49:39 cepek Exp $  */
+/* $Id: g3_parameter.h,v 1.16 2003/12/28 16:42:34 uid66336 Exp $  */
 
 #include <cstddef>
 #include <gnu_gama/model.h>
@@ -33,28 +33,7 @@
 namespace GNU_gama { namespace g3 {
 
 
-  class ParXML {
-  public:
-
-    ParXML() : owner(0), finished(false) {}
-
-    virtual void write_xml(std::ostream& ostr)
-    {
-      if (!finished && owner) owner->write_xml(ostr);
-    }
-    virtual void write_xml_done()  { finished = true;   }  
-    void         write_xml_init()  { finished = false;  }
-    void set_owner(ParXML* parxml) { owner    = parxml; }
-
-  private:
-    ParXML* owner;
-    bool    finished;
-
-  };
-
-
-
-  class Parameter : public ParXML {
+  class Parameter {
   public:
     
     Parameter() : val(0), cor(0), dif(0.05) {}
@@ -65,8 +44,7 @@ namespace GNU_gama { namespace g3 {
     double init_value() const { return val; }
     double correction() const { return cor; }
     double step_size () const { return dif; } 
-    bool   has_index () const { return ind; }
-    std::size_t index() const { return free() ? ind : 0; }
+    std::size_t index() const { return ind; }
 
     void set_init_value(double p) { val = p; cor = 0; }
     void set_correction(double p) { cor = p; }
@@ -84,9 +62,6 @@ namespace GNU_gama { namespace g3 {
     bool free  () const { return state_ &  free_;   }
     bool constr() const { return state_ == constr_; }
 
-    void set_state(const Parameter& p) { state_ = p.state_; }
-    bool cmp_state(const Parameter& p) const { return state_ == p.state_; }
-
   private:
     
     double val;
