@@ -20,10 +20,10 @@
 */
 
 /*
- *  $Id: g3_point.h,v 1.26 2004/04/23 22:01:31 cepek Exp $
+ *  $Id: g3_point.h,v 1.22 2004/01/25 11:07:13 cepek Exp $
  */
 
-#include <string>
+#include <gamalib/pointid.h>
 #include <gnu_gama/g3/g3_parameter.h>
 
 #ifndef GNU_gama__g3_point_h_gnugamag3pointh___gnu_gama_g3point
@@ -34,22 +34,19 @@ namespace GNU_gama {  namespace g3 {
 
   class Model;
 
-  class Point : public ParXML {
+  class Point {
   public:
   
-    typedef std::string   Name;
-    typedef Model         Common;
+    typedef GaMaLib::PointID Name;
+    typedef Model            Common;
 
     Name    name;
     Common* common; 
 
-    Parameter N;
-    Parameter E;
-    Parameter U;
-    Parameter height;
-    Parameter geoid;
-    Parameter dB;
-    Parameter dL;
+    const Parameter& N;
+    const Parameter& E;
+    const Parameter& U;
+    const Parameter& height;
 
     const Parameter& B;
     const Parameter& L;
@@ -98,8 +95,6 @@ namespace GNU_gama {  namespace g3 {
     double Y_dh(double dh) const { return Y() + r23*dh; }
     double Z_dh(double dh) const { return Z() + r33*dh; }
 
-    void write_xml(std::ostream&);
-
   private:
 
     double x_transform(double n, double e, double u);
@@ -128,6 +123,7 @@ namespace GNU_gama {  namespace g3 {
     };
 
     friend class Model;
+    Parameter  N_, E_, U_, height_;
     Parameter  B_, L_, H_, X_, Y_, Z_;
 
     void point_copy(const Point&);
